# coding: utf-8

"""
    Fabric Orchestrator API

    This is Fabric Orchestrator API  # noqa: E501

    OpenAPI spec version: 1.0.1
    Contact: kthare10@unc.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

from fabric_cf.orchestrator.swagger_client.api.slices_api import SlicesApi  # noqa: E501
from fabric_cf.orchestrator.swagger_client.rest import ApiException


class TestSlicesApi(unittest.TestCase):
    """SlicesApi unit test stubs"""

    def setUp(self):
        self.api = SlicesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_slices_create_post(self):
        """Test case for slices_create_post

        Create slice  # noqa: E501
        """
        pass

    def test_slices_delete_slice_id_delete(self):
        """Test case for slices_delete_slice_id_delete

        Delete slice.  # noqa: E501
        """
        pass

    def test_slices_get(self):
        """Test case for slices_get

        Retrieve a listing of user slices  # noqa: E501
        """
        pass

    def test_slices_modify_slice_id_put(self):
        """Test case for slices_modify_slice_id_put

        Modify an existing slice  # noqa: E501
        """
        pass

    def test_slices_renew_slice_id_post(self):
        """Test case for slices_renew_slice_id_post

        Renew slice  # noqa: E501
        """
        pass

    def test_slices_slice_id_get(self):
        """Test case for slices_slice_id_get

        slice properties  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fabric Orchestrator API

    This is Fabric Orchestrator API  # noqa: E501

    OpenAPI spec version: 1.0.1
    Contact: kthare10@unc.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301
from fabric_cf import __VERSION__

NAME = "fabric-orchestrator-client"
VERSION = __VERSION__
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

with open("requirements.txt", "r") as fh:
    requirements = fh.read()

setup(
    name=NAME,
    version=VERSION,
    description="Fabric Orchestrator API",
    author_email="kthare10@unc.edu",
    url="https://github.com/fabric-testbed/OrchestratorClient",
    keywords=["Swagger", "Fabric Orchestrator API"],
    install_requires=requirements,
    packages=find_packages(),
    include_package_data=True,
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.9',
)
